@@ -482,7 +482,7 @@ legacy_nest <- function(...) {
 ##  .................. #< 65355f4d719ea07c474f69fceb2d1ef2 ># ..................
 ##  Legacy unnest                                                           ####
 
-
+# TODO Change to new unnest
 legacy_unnest <- function(...) {
   if (tidyr_new_interface()) {
     tidyr::unnest_legacy(...)
@@ -964,3 +964,8 @@ is_newer_lme4 <- function(){
   out
 }
 
+is_dplyr_1 <- function() {
+  v <- get_pkg_version("dplyr")
+  v$major >= 1 || (v$minor == 8 && v$patch == 99 && v$dev >= 9003)
+}
+
